import React, { lazy, Suspense } from 'react';
import Footer from '@/components/Footer';
import SimpleNavbar from '@/components/SimpleNavbar';
import DeferredInteractiveComponents from '@/components/DeferredInteractiveComponents';
import CriticalHeroSection from '@/components/CriticalHeroSection';
import EssentialSchemaMarkup from '@/components/EssentialSchemaMarkup';
import { Helmet } from 'react-helmet';
import { useSimpleVisibility } from '@/hooks/useSimpleVisibility';
import { useLazyContentData } from '@/components/LazyContentLoader';

// Import critical data directly for immediate availability
import { mainServices } from '@/data/services';
import { stats } from '@/data/stats';

// Critical components loaded immediately - only above the fold
import LazyContentSections from '@/components/LazyContentSections';

// Lazy-loaded components - below the fold
const CompanyTagline = lazy(() => import('@/components/CompanyTagline'));
const CoreFeatures = lazy(() => import('@/components/CoreFeatures'));
const StatSection = lazy(() => import('@/components/StatSection'));
const ServicesSection = lazy(() => import('@/components/ServicesSection'));
const CaseStudiesSection = lazy(() => import('@/components/CaseStudiesSection'));
const FounderProfile = lazy(() => import('@/components/FounderProfile'));
const GovernmentHealthRisks = lazy(() => import('@/components/GovernmentHealthRisks'));

// Skeleton placeholders for different section types
const StatsSkeleton = () => (
  <section className="py-16 bg-gray-50">
    <div className="container-custom">
      <div className="grid grid-cols-2 md:grid-cols-4 gap-8">
        {[...Array(4)].map((_, i) => (
          <div key={i} className="text-center">
            <div className="h-12 w-16 bg-gray-200 rounded mx-auto mb-2 animate-pulse"></div>
            <div className="h-4 bg-gray-200 rounded mb-2 animate-pulse"></div>
          </div>
        ))}
      </div>
    </div>
  </section>
);

const ServicesSkeleton = () => (
  <section className="py-16 bg-white">
    <div className="container-custom">
      <div className="text-center max-w-3xl mx-auto mb-12">
        <div className="h-8 bg-gray-200 rounded mb-4 animate-pulse"></div>
        <div className="h-4 bg-gray-200 rounded animate-pulse"></div>
      </div>
      <div className="grid md:grid-cols-3 gap-8">
        {[...Array(3)].map((_, i) => (
          <div key={i} className="p-6 border rounded-lg">
            <div className="h-12 w-12 bg-gray-200 rounded mb-4 animate-pulse"></div>
            <div className="h-6 bg-gray-200 rounded mb-2 animate-pulse"></div>
            <div className="h-4 bg-gray-200 rounded animate-pulse"></div>
          </div>
        ))}
      </div>
    </div>
  </section>
);

const ComponentLoader = () => (
  <div className="h-20 flex items-center justify-center">
    <div className="w-6 h-6 border-2 border-primary border-t-transparent rounded-full animate-spin"></div>
  </div>
);

const Index = () => {
  const shouldLoadHeavyComponents = useSimpleVisibility();
  const lazyData = useLazyContentData(shouldLoadHeavyComponents);
  
  // Static hero props with fallback for better LCP - avoid dynamic content initially
  const heroProps = {
    title: "Professional Mould Removal London - Expert Mould Removal Services",
    subtitle: "London's leading mould removal company providing professional mould removal services. Our mould cleaners London specialists offer emergency mould removal near me with certified expertise across all London areas.",
    benefits: [
      "Leading Mould Removal Company London with Professional Training",
      "Safe for Families, Tenants & Pets – Eco-Friendly Methods", 
      "Mould Specialist London You Can Trust"
    ]
  };
  
  return (
    <>
      <Helmet>
        <title>Mould Removal London | Expert Professional Service | AirFresh</title>
        <meta name="description" content="Professional mould removal London services. Leading mould removal company offering mould cleaners London, emergency mould removal near me, and certified mould specialist London solutions." />
        <link rel="canonical" href="https://mouldremovallondon.co.uk/" />
        
        {/* Additional meta tags to prevent index.html indexing */}
        <meta name="robots" content="index, follow" />
        <meta property="og:url" content="https://mouldremovallondon.co.uk/" />
      </Helmet>
      
      <EssentialSchemaMarkup 
        businessName="AirFresh Mould Removal London - Professional Mould Specialists"
        description="London's professional mould specialists helping landlords, tenants, and homeowners address mould issues and improve air quality across all London boroughs."
        rating={{
          ratingValue: 4.8,
          ratingCount: 127
        }}
        pageName="Professional Mould Specialists London | AirFresh"
        pageDescription="Experienced mould specialists across London with professional training. We help landlords, tenants, and homeowners address mould issues and improve air quality."
        pageUrl="https://mouldremovallondon.co.uk/"
      />
      
      <DeferredInteractiveComponents>
        <SimpleNavbar />
      </DeferredInteractiveComponents>
      
      <main>
        <CriticalHeroSection {...heroProps} />
        
        <Suspense fallback={<ComponentLoader />}>
          <CompanyTagline />
        </Suspense>

        {/* Lazy load CoreFeatures after initial render */}
        <Suspense fallback={<ComponentLoader />}>
          <CoreFeatures />
        </Suspense>

        {/* Below-the-fold sections - lazy loaded with skeletons */}
        <Suspense fallback={<StatsSkeleton />}>
          <StatSection stats={stats} />
        </Suspense>
        
        <Suspense fallback={<ServicesSkeleton />}>
        <ServicesSection 
          title="Our Professional Mould Removal Services in London"
          subtitle="Expert black mould removal and mould remediation solutions from London's experienced mould specialists"
          services={mainServices}
          showViewAllButton={true}
        />
        </Suspense>

        {/* Case Studies Section */}
        <Suspense fallback={<ComponentLoader />}>
          <CaseStudiesSection maxItems={1} isHomepage={true} />
        </Suspense>

        {/* Lazy load FounderProfile after initial render */}
        <Suspense fallback={<ComponentLoader />}>
          <FounderProfile />
        </Suspense>

        {/* Lazy load GovernmentHealthRisks after initial render */}
        <Suspense fallback={<ComponentLoader />}>
          <GovernmentHealthRisks 
            title="Why Professional Mould Assessment Matters"
            showFullContent={true}
          />
        </Suspense>

        {/* Heavy components - load only when needed */}
        <LazyContentSections 
          shouldLoad={shouldLoadHeavyComponents}
          lazyData={lazyData}
        />
      </main>
      
      <Footer />
    </>
  );
};

export default Index;
